==> qmmp_1.3.1.orig.tar.bz2: qmmp-1.3.1/src/plugins/General/trackchange/translations/trackchange_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Track Change Plugin Settings</source>
        <translation>トラック変化プラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <location filename="../settingsdialog.ui" line="42"/>
        <location filename="../settingsdialog.ui" line="52"/>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Command to run when Qmmp starts new track</source>
        <translation>トラックを新たに再生し始めるときに実行するコマンド</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="83"/>
        <source>Command to run toward to end of a track</source>
        <translation>トラックの終了時に合わせて実行するコマンド</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Command to run when Qmmp reaches the end of the playlist</source>
        <translation>プレイリストの最終演目に達したときに実行するコマンド</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>Command to run when title changes (i.e. network streams title)</source>
        <translation>タイトルが変化したときに実行するコマンド (ネット放送用)</translation>
    </message>
</context>
<context>
    <name>TrackChangeFactory</name>
    <message>
        <location filename="../trackchangefactory.cpp" line="30"/>
        <source>Track Change Plugin</source>
        <translation>トラック変化プラグイン</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="50"/>
        <source>About Track Change Plugin</source>
        <translation>トラック変化プラグインについて</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="51"/>
        <source>Qmmp Track Change Plugin</source>
        <translation>QMMP トラック変化プラグイン</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="52"/>
        <source>This plugin executes external command when current track is changed</source>
        <translation>このプラグインはトラック (演目) が切り換わる際に外部コマンドを実行します。</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/General/trackchange/translations/trackchange_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Track Change Plugin Settings</source>
        <translation>トラック変化プラグイン設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="39"/>
        <location filename="../settingsdialog.ui" line="56"/>
        <location filename="../settingsdialog.ui" line="73"/>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Command to run when Qmmp starts new track</source>
        <translation>トラックを新たに再生し始めるときに実行するコマンド</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="46"/>
        <source>Command to run toward to end of a track</source>
        <translation>トラックの終了時に合わせて実行するコマンド</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Command to run when Qmmp reaches the end of the playlist</source>
        <translation>プレイリストの最終演目に達したときに実行するコマンド</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Command to run when title changes (i.e. network streams title)</source>
        <translation>タイトルが変化したときに実行するコマンド (ネット放送用)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="97"/>
        <source>Command to run on application startup:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="104"/>
        <source>Command to run on application exit:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrackChangeFactory</name>
    <message>
        <location filename="../trackchangefactory.cpp" line="30"/>
        <source>Track Change Plugin</source>
        <translation>トラック変化プラグイン</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="50"/>
        <source>About Track Change Plugin</source>
        <translation>トラック変化プラグインについて</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="51"/>
        <source>Qmmp Track Change Plugin</source>
        <translation>QMMP トラック変化プラグイン</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="52"/>
        <source>This plugin executes external command when current track is changed</source>
        <translation>このプラグインはトラック (演目) が切り換わる際に外部コマンドを実行します。</translation>
    </message>
    <message>
        <location filename="../trackchangefactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>制作: Илья Котов (Ilya Kotov) &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
